==> bizext.php5.3_5.6.zip: bizext/lib/spout/Reader/Exception/XMLProcessingException.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPvbEof7ebCwcJVjVigQf3uGsqUYBfPE7kb7BUE504K5YwtJJJJbYFHqr2OFqnFRlzc+zOdpF
cAGZQ9WM8rgx8d87QzADZd41zgotelYee2cS6xK7sJ4mtwFcXqrYRnf0rXJP/oJAM57yTInAhpId
DUQl4Xz2Ws+BCDKg4RQTWp6y8z6DQyVeOGfoiL+MDneB80HKHtW1x9oxWeXrclR2SdJwxzY0V2dO
PZhPXgAOAIUS4382lNZTWELkHUt+HvDUkvsBYU+Z1WmNWjFKDvRKchY2lY5TisCN01NGJEOIHOKI
dqqNjin6Bjh2OqVeJs2qS6MnvpX/+bFZq2zH3eQm7RLooJvnz8wevNCcgCRlIq8q5UbwZFMggaS2
XiBbbexvocNKo1b+rYsPZpudVIV/3/1NSOr64pMb77Ixp4rsndzHUcyn37rU8jdxevudqrsNyF6n
5PaD+lF5/nK4SqoZG8xe44+BnOEThTWgRhYSCudRvndTcTjvygMKLD/dO4xh/DMnfcENbeo1ZFgO
8esnlPWgbA8pz7r1XMwN4oDUAlgrp4duTjEm/udY7gyfuMgSMN7WbX9kMmDqUnjfsOz6xg7PqAGx
y1sBP2PdBdTnHeYP4Iul30aC/x4IfCAIeEuziO2Ou/NH8YJWKL3CiMRMji9eT1xqqmz3cNYDadpG
ksPZsrAmKbNMH3qK3BfMBMKPDoLDsvzPukmHcyRhA1hpalZMr5tiOk+rEDnT4CEwPJ0xbMTX1sRg
CnWEzP7ELlRif3tFB18SAFhW3pZUo3CfWugQjLMNkA3pgYoPoWLIua+h99wU4G==

==> bizext.php7.1.zip: bizext/lib/spout/Reader/Exception/XMLProcessingException.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPoZLXun2FNoZhs0IhmMo0XhQCekklkH1ZC0x+JPkGVwmalFjaYA0TadLBFFzH4VVfn3lCU/m
zqcbfrWWZp+iii2I3Acd82D3lS+SSA2F/HDvwHaQ+L/MIXhjZ+Quairoqk11vJC0vSGld4HaWY3t
rVIafiGZM37iDoWCQirSfFlEUPTxps0NE2hZzjgtRQq+ELLFUGstq1aTxC9NCPThNDgKkeM4IBIT
6fTYdhnXDCz0mVKxhe6NiNXmRL0MP6iZ1/Wu4kcs7ZymMnqZVMxfy7VycPiUYvWMsNGR9VVm1bvm
EFex3MiuUIGmv7AWezw+fmAcMBYwqVaHE3Q4pPONGKbN9zUEFgiKKQHJNojJ+AdpGL4qDsmqIMzB
805vr2MSqZBGh9VmY4VLoP9yoGhMS2HDgIxfvONc0mptvbhPmB0K1P3PjQY2RlTDmVYI3OEwvQh5
0/VwnofhkgQjAWjLCQEBQNq+OqbnTPKhol00nkgOn7sIpUK7YoAwuEyP4dqMls8hX2/r+AcswdH2
EmZ0F+f7qsuz52PQXEkvKpQccoLYM+AVf7M8u/aVgy4K57Whvbmj41zV4PLWENLnyrmHybZxW7xg
2WciDKlyuJUVjEmZUexx3KT0P2HhlhJYaQ0BpmznbbR4YHNwsh0vCdYjRmU//AHy6MLy0iWizv2F
nqtfrIje33ilsLI2hdAD3PH6v9DpSJu7RGhNqiXJbeUReCv8fmgC/VnATl98ScLPcTxqY8nVP0ST
fJ0TSFjg9N0rE0znwX23RAiuhErk0XdQRd8iBm70MviJSmbXt+wHpdNvKrEjVlqpLuYmV3DVrnSS
fFhJLfnJD8Y2aUINb6Y4T/TKxtEWVJyfaA6FCdJoRXAZLllwV6QZeEtExxoDmex7Hf4TxmOUoOXx
QlghaASblQAxwcK=
